@@ -1,12 +1,15 @@
-#line 1 "inc/ExtUtils/AutoInstall.pm - /usr/local/svk-1.06/perl/ExtUtils/AutoInstall.pm"
+#line 1 "inc/ExtUtils/AutoInstall.pm - /Library/Perl/5.8.1/ExtUtils/AutoInstall.pm"
+# $File: //member/autrijus/ExtUtils-AutoInstall/lib/ExtUtils/AutoInstall.pm $ 
+# $Revision: #14 $ $Change: 10538 $ $DateTime: 2004/04/29 17:55:36 $ vim: expandtab shiftwidth=4
+
 package ExtUtils::AutoInstall;
-$ExtUtils::AutoInstall::VERSION = '0.63';
+$ExtUtils::AutoInstall::VERSION = '0.61';
 
 use strict;
 use Cwd ();
 use ExtUtils::MakeMaker ();
 
-#line 312
+#line 307
 
 # special map on pre-defined feature sets
 my %FeatureMap = (
@@ -354,10 +357,8 @@ sub _install_cpan {
     my %args;
 
     require CPAN; CPAN::Config->load;
-    require Config;
 
-    return unless _can_write(MM->catfile($CPAN::Config->{cpan_home}, 'sources'))
-              and _can_write($Config::Config{sitelib});
+    return unless _can_write(MM->catfile($CPAN::Config->{cpan_home}, 'sources'));
 
     # if we're root, set UNINST=1 to avoid trouble unless user asked for it.
     my $makeflags = $CPAN::Config->{make_install_arg} || '';
@@ -487,7 +488,8 @@ sub _can_write {
     my $path = shift;
     mkdir ($path, 0755) unless -e $path;
 
-    return 1 if -w $path;
+    require Config;
+    return 1 if -w $path and -w $Config::Config{sitelib};
 
     print << ".";
 *** You are not allowed to write to the directory '$path';
@@ -644,4 +646,4 @@ installdeps ::
 
 __END__
 
-#line 978
+#line 972
