@@ -1,12 +1,14 @@
-#line 1 "inc/Module/AutoInstall.pm - /usr/local/lib/perl5/site_perl/5.8.5/Module/AutoInstall.pm"
+#line 1 "inc/Module/AutoInstall.pm - /Library/Perl/5.8.6/Module/AutoInstall.pm"
 package Module::AutoInstall;
-$Module::AutoInstall::VERSION = '1.00';
 
 use strict;
 use Cwd                 ();
 use ExtUtils::MakeMaker ();
 
-#line 221
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.02';
+}
 
 # special map on pre-defined feature sets
 my %FeatureMap = (
@@ -19,7 +21,8 @@ my ( @Missing, @Existing,  %DisabledTests, $UnderCPAN,     $HasCPANPLUS );
 my ( $Config,  $CheckOnly, $SkipInstall,   $AcceptDefault, $TestOnly );
 my ( $PostambleActions, $PostambleUsed );
 
-_accept_default( !-t STDIN );      # see if it's a non-interactive session
+# See if it's a testing or non-interactive session
+_accept_default( $ENV{AUTOMATED_TESTING} or ! -t STDIN ); 
 _init();
 
 sub _accept_default {
@@ -88,11 +91,11 @@ sub _prompt {
 # the workhorse
 sub import {
     my $class = shift;
-    my @args = @_ or return;
+    my @args  = @_ or return;
     my $core_all;
 
     print "*** $class version " . $class->VERSION . "\n";
-    print "*** Checking for dependencies...\n";
+    print "*** Checking for Perl dependencies...\n";
 
     my $cwd = Cwd::cwd();
 
@@ -234,22 +237,25 @@ sub import {
 # CPAN.pm is non-reentrant, so check if we're under it and have no CPANPLUS
 sub _check_lock {
     return unless @Missing;
-    return if _has_cpanplus();
+    _load_cpan();
 
-    require CPAN;
-    CPAN::Config->load;
+    # Find the CPAN lock-file
     my $lock = MM->catfile( $CPAN::Config->{cpan_home}, ".lock" );
+    return unless -f $lock;
 
-    if (    -f $lock
-        and open( LOCK, $lock )
-        and ( $^O eq 'MSWin32' ? _under_cpan() : <LOCK> == getppid() )
-        and ( $CPAN::Config->{prerequisites_policy} || '' ) ne 'ignore' )
-    {
-        print << '.';
+    # Check the lock
+    local *LOCK;
+    return unless open(LOCK, $lock);
+
+    if (
+            ( $^O eq 'MSWin32' ? _under_cpan() : <LOCK> == getppid() )
+        and ( $CPAN::Config->{prerequisites_policy} || '' ) ne 'ignore'
+    ) {
+        print <<'END_MESSAGE';
 
 *** Since we're running under CPAN, I'll just let it take care
     of the dependency's installation later.
-.
+END_MESSAGE
         $UnderCPAN = 1;
     }
 
@@ -294,10 +300,9 @@ sub install {
         @modules = @newmod;
     }
 
-    if ( _has_cpanplus() ) {
+    if ( ! $UnderCPAN and _has_cpanplus() ) {
         _install_cpanplus( \@modules, \@config );
-    }
-    else {
+    } else {
         _install_cpan( \@modules, \@config );
     }
 
@@ -320,38 +325,35 @@ sub install {
 
 sub _install_cpanplus {
     my @modules   = @{ +shift };
-    my @config    = @{ +shift };
+    my @config    = _cpanplus_config( @{ +shift } );
     my $installed = 0;
 
     require CPANPLUS::Backend;
     my $cp   = CPANPLUS::Backend->new;
     my $conf = $cp->configure_object;
 
-    return
-      unless _can_write(
-          $conf->can('conf')
-        ? $conf->get_conf('base')      # 0.05x+
-        : $conf->_get_build('base')    # 0.04x
-      );
+    return unless $conf->can('conf') # 0.05x+ with "sudo" support
+               or _can_write($conf->_get_build('base'));  # 0.04x
 
     # if we're root, set UNINST=1 to avoid trouble unless user asked for it.
     my $makeflags = $conf->get_conf('makeflags') || '';
     if ( UNIVERSAL::isa( $makeflags, 'HASH' ) ) {
-
         # 0.03+ uses a hashref here
         $makeflags->{UNINST} = 1 unless exists $makeflags->{UNINST};
-    }
-    else {
 
+    } else {
         # 0.02 and below uses a scalar
         $makeflags = join( ' ', split( ' ', $makeflags ), 'UNINST=1' )
           if ( $makeflags !~ /\bUNINST\b/ and eval qq{ $> eq '0' } );
+
     }
     $conf->set_conf( makeflags => $makeflags );
     $conf->set_conf( prereqs   => 1 );
 
+    
+
     while ( my ( $key, $val ) = splice( @config, 0, 2 ) ) {
-        eval { $conf->set_conf( $key, $val ) };
+        $conf->set_conf( $key, $val );
     }
 
     my $modtree = $cp->module_tree;
@@ -376,15 +378,13 @@ sub _install_cpanplus {
             if ( $rv and ( $rv->{ $obj->{module} } or $rv->{ok} ) ) {
                 print "*** $pkg successfully installed.\n";
                 $success = 1;
-            }
-            else {
+            } else {
                 print "*** $pkg installation cancelled.\n";
                 $success = 0;
             }
 
             $installed += $success;
-        }
-        else {
+        } else {
             print << ".";
 *** Could not find a version $ver or above for $pkg; skipping.
 .
@@ -396,19 +396,41 @@ sub _install_cpanplus {
     return $installed;
 }
 
+sub _cpanplus_config {
+	my @config = ();
+	while ( @_ ) {
+		my ($key, $value) = (shift(), shift());
+		if ( $key eq 'prerequisites_policy' ) {
+			if ( $value eq 'follow' ) {
+				$value = CPANPLUS::Internals::Constants::PREREQ_INSTALL();
+			} elsif ( $value eq 'ask' ) {
+				$value = CPANPLUS::Internals::Constants::PREREQ_ASK();
+			} elsif ( $value eq 'ignore' ) {
+				$value = CPANPLUS::Internals::Constants::PREREQ_IGNORE();
+			} else {
+				die "*** Cannot convert option $key = '$value' to CPANPLUS version.\n";
+			}
+		} else {
+			die "*** Cannot convert option $key to CPANPLUS version.\n";
+		}
+	}
+	return @config;
+}
+
 sub _install_cpan {
     my @modules   = @{ +shift };
     my @config    = @{ +shift };
     my $installed = 0;
     my %args;
 
-    require CPAN;
-    CPAN::Config->load;
+    _load_cpan();
     require Config;
 
-    return
-      unless _can_write( MM->catfile( $CPAN::Config->{cpan_home}, 'sources' ) )
-      and _can_write( $Config::Config{sitelib} );
+    if (CPAN->VERSION < 1.80) {
+        # no "sudo" support, probe for writableness
+        return unless _can_write( MM->catfile( $CPAN::Config->{cpan_home}, 'sources' ) )
+                  and _can_write( $Config::Config{sitelib} );
+    }
 
     # if we're root, set UNINST=1 to avoid trouble unless user asked for it.
     my $makeflags = $CPAN::Config->{make_install_arg} || '';
@@ -553,7 +575,8 @@ sub _can_write {
     if (
         eval '$>' and lc(`sudo -V`) =~ /version/ and _prompt(
             qq(
-==> Should we try to re-execute the autoinstall process with 'sudo'?), 'y'
+==> Should we try to re-execute the autoinstall process with 'sudo'?),
+            ((-t STDIN) ? 'y' : 'n')
         ) =~ /^[Yy]/
       )
     {
@@ -594,6 +617,19 @@ sub _load {
     return eval { require $file; $mod->VERSION } || ( $@ ? undef: 0 );
 }
 
+# Load CPAN.pm and it's configuration
+sub _load_cpan {
+    return if $CPAN::VERSION;
+    require CPAN;
+    if ( $CPAN::HandleConfig::VERSION ) {
+        # Newer versions of CPAN have a HandleConfig module
+        CPAN::HandleConfig->load;
+    } else {
+    	# Older versions had the load method in Config directly
+        CPAN::Config->load;
+    }
+}
+
 # compare two versions, either use Sort::Versions or plain comparison
 sub _version_check {
     my ( $cur, $min ) = @_;
@@ -657,7 +693,7 @@ sub _make_args {
     $PostambleActions = (
         $missing
         ? "\$(PERL) $0 --config=$config --installdeps=$missing"
-        : "\@\$(NOOP)"
+        : "\$(NOECHO) \$(NOOP)"
     );
 
     return %args;
@@ -698,7 +734,7 @@ sub postamble {
     return << ".";
 
 config :: installdeps
-\t\@\$(NOOP)
+\t\$(NOECHO) \$(NOOP)
 
 checkdeps ::
 \t\$(PERL) $0 --checkdeps
@@ -714,4 +750,4 @@ installdeps ::
 
 __END__
 
-#line 950
+#line 988
